@@ -37,9 +37,9 @@
 #include <KAboutData>
 #include <QApplication>
 #include <QCommandLineParser>
+#include <cstdlib>
+#include <ctime>
 #include <iostream>
-#include <stdlib.h>
-#include <time.h>
 
 using namespace KCalendarCore;
 using namespace std;
@@ -550,7 +550,7 @@ int main(int argc, char *argv[])
     QElapsedTimer t;
     t.start();
     loop.exec();
-    qCDebug(KONSOLEKALENDAR_LOG) << "Calendar loaded in" << t.elapsed() << "ms; success=" << calendar->isLoaded()
+    qCDebug(KONSOLEKALENDAR_LOG) << "Calendar loaded in" << t.elapsed() << "ms; success=" << !calendar->isLoading()
                                  << "; num incidences=" << calendar->incidences().count();
 
     variables.setCalendar(calendar);
